<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>ArtNetPlugin</name>
    <message>
        <location filename="artnetplugin.cpp" line="97"/>
        <source>This plugin provides DMX output for devices supporting the ArtNet communication protocol.</source>
        <oldsource>This plugin provides output for devices supporting the ArtNet communication protocol.</oldsource>
        <translation>Este plugin provee Salida DMX para dispositivos que soportan el protocolo de comunicación ArtNet.</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="144"/>
        <source>Output</source>
        <translation>Salida</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="148"/>
        <location filename="artnetplugin.cpp" line="298"/>
        <source>Status: Not open</source>
        <translation>Estado: No abierto</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="151"/>
        <source>Status: Open</source>
        <translation>Estado: Abierto</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="156"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="158"/>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="159"/>
        <source>Can receive nodes information</source>
        <oldsource>Can receive node information</oldsource>
        <translation>Puede recibir información de nodos</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="162"/>
        <source>Nodes discovered: </source>
        <translation>Nodos descubiertos: </translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="165"/>
        <source>Packets sent: </source>
        <translation>Paquetes enviados: </translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="294"/>
        <source>Input</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="303"/>
        <source>Bind failed</source>
        <translation>Falló el enlace</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="305"/>
        <source>Open</source>
        <translation>Abierto</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="306"/>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="309"/>
        <source>Packets received: </source>
        <translation>Paquetes recibidos: </translation>
    </message>
</context>
<context>
    <name>ConfigureArtNet</name>
    <message>
        <location filename="configureartnet.ui" line="33"/>
        <source>Configure ArtNet Plugin</source>
        <translation>Configurar el Plugin ArtNet</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="43"/>
        <source>Universes Configuration</source>
        <translation>Configuración de Universos</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="49"/>
        <source>Configuration of the patched universes</source>
        <translation>Configuración de universos patcheados</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="57"/>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="62"/>
        <source>Universe</source>
        <translation>Universo</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="67"/>
        <source>IP Address</source>
        <translation>Direccón IP</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="72"/>
        <source>ArtNet Universe</source>
        <translation>Universo ArtNet</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="77"/>
        <source>Transmission Mode</source>
        <translation>Modo de Transmisión</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="87"/>
        <source>Seconds to wait for an interface to be ready</source>
        <translation>Segundos a esperar que esté preparada una interfaz</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="120"/>
        <source>Nodes Tree</source>
        <translation>Árbol de Nodos</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="130"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="135"/>
        <source>Short Name</source>
        <translation>Nombre Corto</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="140"/>
        <source>Long Name</source>
        <translation>Nombre Largo</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="86"/>
        <source>%1 nodes</source>
        <translation>%1 nodos</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="124"/>
        <source>Inputs</source>
        <translation>Entradas</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="130"/>
        <source>Outputs</source>
        <translation>Salidas</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="181"/>
        <source>Standard</source>
        <translation>Estándar</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="182"/>
        <source>Full</source>
        <translation>Completo</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="183"/>
        <source>Partial</source>
        <translation>Parcial</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="198"/>
        <source>Invalid IP</source>
        <translation>IP inválido</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="198"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 no es un IP válido.
Por favor arréglelo antes de confirmar.</translation>
    </message>
</context>
</TS>
